#ifndef SVNSTRINGS_H
#define SVNSTRINGS_H

const wxString svnNO_FILES_TO_DISPLAY     = wxT("No Files to Display");
const wxString svnMODIFIED_FILES          = wxT("Modified Files");
const wxString svnADDED_FILES             = wxT("Added Files");
const wxString svnDELETED_FILES           = wxT("Deleted Files");
const wxString svnCONFLICTED_FILES        = wxT("Conflicted Files");
const wxString svnUNVERSIONED_FILES       = wxT("Unversioned Files");
const wxString svnCONSOLE_TEXT            = wxT("Svn");
const wxString svnANOTHER_PROCESS_RUNNING = wxT("MESSAGE: Another process is already running.\nMESSAGE: Ignoring last command.\n");
#endif // SVNSTRINGS_H
